# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/04_plots.ipynb.

# %% auto 0
__all__ = ['plot_library_size', 'make_qc_figs']

# %% ../nbs/04_plots.ipynb 3
# NOTE: needed for python 3.10 forward compatibility with scanpy as 
# scanpy uses Iterable which is deprecated in 3.10
import collections.abc
#hyper needs the four following aliases to be done manually.
collections.Iterable = collections.abc.Iterable
collections.Mapping = collections.abc.Mapping
collections.MutableSet = collections.abc.MutableSet
collections.MutableMapping = collections.abc.MutableMapping

# %% ../nbs/04_plots.ipynb 4
import os, copy

import numpy as np, pandas as pd
import scanpy as sc

from typing import TypeAlias, List, Sequence, Tuple

# %% ../nbs/04_plots.ipynb 5
from degex.static import (
    TOTAL_COUNTS, PCT_COUNTS_MITO, PCT_COUNTS_RIBO,
)
from .types import (AnnData, )
from .utils import (make_qc_fig_filename)

# %% ../nbs/04_plots.ipynb 6
def plot_library_size(adata: AnnData, lower: float, upper: float):
    sc.plot.plot_library_size(
        adata.X, log=False, 
        title='Library Size', 
        cutoff=(lower, upper)
    )

# %% ../nbs/04_plots.ipynb 7
def make_qc_figs(
    adata: AnnData,
    save_dir: str,
    study_name: str,
) -> None:
    x = 'log10_total_counts'
    y = 'n_genes_by_counts'    
    
    sc.pl.scatter(
        adata, x=x, y=y, color=PCT_COUNTS_MITO, 
        save=make_qc_fig_filename(
            save_dir, study_name, x, y, 'mitopct'
        )        
    )
    sc.pl.scatter(
        adata, x=x, y=y, color=PCT_COUNTS_RIBO, 
        save=make_qc_fig_filename(
            save_dir, study_name, x, y, 'ribopcg'
        )
    )
    x = TOTAL_COUNTS
    sc.pl.scatter(
        adata, x=x, y=y, color=PCT_COUNTS_MITO,
        save=make_qc_fig_filename(
            save_dir, study_name, x, y, 'mitopct'
        ) 
    )
    sc.pl.scatter(
        adata, x=x, y=y, color=PCT_COUNTS_RIBO, 
        save=make_qc_fig_filename(
            save_dir, study_name, x, y, 'ribopcg'
        )
    )
    sc.pl.scatter(
        adata, x=x, y=y,         
        color="pct_counts_in_top_50_genes", 
        save=make_qc_fig_filename(
            save_dir, study_name, x, y, 'top50pct'
        )
    )

    x = PCT_COUNTS_MITO
    y = 'pct_counts_in_top_50_genes'
    sc.pl.scatter(
        adata, x=x, y=y, 
        color="n_genes_by_counts", 
        save=make_qc_fig_filename(
            save_dir, study_name, x, y, 'ngenes'
        )
    )
    x = PCT_COUNTS_RIBO
    sc.pl.scatter(
        adata, x=x, y=y,
        color="n_genes_by_counts", 
        save=make_qc_fig_filename(
            save_dir, study_name, x, y, 'ngenes'
        )
    )
    sc.pl.scatter(
        adata, x=x, y=y,        
        color=PCT_COUNTS_MITO, 
        save=make_qc_fig_filename(
            save_dir, study_name, x, y, 'ngenes'
        )
    )
